@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: gutils.py 1207 2009-06-08 21:40:30Z piotrek $'
+__revision__ = '$Id: gutils.py 1392 2010-01-09 22:45:16Z piotrek $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -21,41 +21,44 @@ __revision__ = '$Id: gutils.py 1207 2009-06-08 21:40:30Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-import string
+import gzip
+import htmlentitydefs
+import logging
 import os
+import re
+import string
 import sys
+import webbrowser
+from StringIO import StringIO
 try:
     import gtk
-    import gobject
     import db
 except:
+    gtk = None
     pass
-import htmlentitydefs
-import re
-import webbrowser
-import logging
 log = logging.getLogger("Griffith")
 
-url_re = re.compile('^\w+://')
-entity = re.compile(r'\&.\w*?\;')
-html_tags = re.compile(r'\<.*?\>')
+ENTITY = re.compile(r'\&.\w*?\;')
+
 
 def remove_accents(txt, encoding='iso-8859-1'):
     d = {192: u'A', 193: u'A', 194: u'A', 195: u'A', 196: u'A', 197: u'A',
-            199: u'C', 200: u'E', 201: u'E', 202: u'E', 203: u'E', 204: u'I',
-            205: u'I', 206: u'I', 207: u'I', 209: u'N', 210: u'O', 211: u'O',
-            212: u'O', 213: u'O', 214: u'O', 216: u'O', 217: u'U', 218: u'U',
-            219: u'U', 220: u'U', 221: u'Y', 224: u'a', 225: u'a', 226: u'a',
-            227: u'a', 228: u'a', 229: u'a', 231: u'c', 232: u'e', 233: u'e',
-            234: u'e', 235: u'e', 236: u'i', 237: u'i', 238: u'i', 239: u'i',
-            241: u'n', 242: u'o', 243: u'o', 244: u'o', 245: u'o', 246: u'o',
-            248: u'o', 249: u'u', 250: u'u', 251: u'u', 252: u'u', 253: u'y',
-            255: u'y'}
+         199: u'C', 200: u'E', 201: u'E', 202: u'E', 203: u'E', 204: u'I',
+         205: u'I', 206: u'I', 207: u'I', 209: u'N', 210: u'O', 211: u'O',
+         212: u'O', 213: u'O', 214: u'O', 216: u'O', 217: u'U', 218: u'U',
+         219: u'U', 220: u'U', 221: u'Y', 224: u'a', 225: u'a', 226: u'a',
+         227: u'a', 228: u'a', 229: u'a', 231: u'c', 232: u'e', 233: u'e',
+         234: u'e', 235: u'e', 236: u'i', 237: u'i', 238: u'i', 239: u'i',
+         241: u'n', 242: u'o', 243: u'o', 244: u'o', 245: u'o', 246: u'o',
+         248: u'o', 249: u'u', 250: u'u', 251: u'u', 252: u'u', 253: u'y',
+         255: u'y'}
     return unicode(txt, encoding).translate(d)
 
+
 def is_number(x):
     return isinstance(x, int)
 
+
 def find_next_available(gsql):
     """
     finds next available movie number.
@@ -79,19 +82,21 @@ def find_next_available(gsql):
         number = first + 1
         return number
 
+
 def trim(text, key1, key2):
     p1 = string.find(text, key1)
     if p1 == -1:
         return ''
     else:
-        p1 = p1+len(key1)
+        p1 = p1 + len(key1)
     p2 = string.find(text[p1:], key2)
     if p2 == -1:
         return ""
     else:
-        p2 = p1+p2
+        p2 = p1 + p2
     return text[p1:p2]
 
+
 def regextrim(text, key1, key2):
     obj = re.search(key1, text)
     if obj is None:
@@ -105,19 +110,23 @@ def regextrim(text, key1, key2):
         p2 = p1 + obj.start()
     return text[p1:p2]
 
+
 def after(text, key):
-    p1 = string.find(text,key)
-    return text[p1+len(key):]
+    p1 = string.find(text, key)
+    return text[p1 + len(key):]
+
 
 def before(text, key):
-    p1 = string.find(text,key)
+    p1 = string.find(text, key)
     return text[:p1]
 
+
 def gescape(text):
-    text=string.replace(text,"'", "''")
-    text=string.replace(text,"--", "-")
+    text = string.replace(text, "'", "''")
+    text = string.replace(text, "--", "-")
     return text
 
+
 def progress(blocks, size_block, size):
     transfered = blocks * size_block
     if size > 0 and transfered > size:
@@ -128,6 +137,7 @@ def progress(blocks, size_block, size):
 
 # functions to handle comboboxentry stuff
 
+
 def set_model_from_list(cb, items):
     """Setup a ComboBox or ComboBoxEntry based on a list of strings."""
     model = gtk.ListStore(str)
@@ -141,6 +151,7 @@ def set_model_from_list(cb, items):
         cb.pack_start(cell, True)
         cb.add_attribute(cell, 'text', 0)
 
+
 def on_combo_box_entry_changed(widget):
     model = widget.get_model()
     m_iter = widget.get_active_iter()
@@ -152,10 +163,13 @@ def on_combo_box_entry_changed(widget):
     else:
         return 0
 
+
 def on_combo_box_entry_changed_name(widget):
     return widget.get_active_text()
 
+
 def convert_entities(text):
+
     def conv(ents):
         entities = htmlentitydefs.entitydefs
         ents = ents.group(0)
@@ -169,7 +183,7 @@ def convert_entities(text):
                 print("error occurred while converting entity %s: %s" % (ents, ex))
 
             # check if it still needs conversion
-            if not entity.search(ents):
+            if not ENTITY.search(ents):
                 return ents
 
         if ents[1] == '#':
@@ -182,13 +196,14 @@ def convert_entities(text):
         else:
             return
 
-    in_entity = entity.search(text)
+    in_entity = ENTITY.search(text)
     if not in_entity:
         return text
     else:
         ctext = in_entity.re.sub(conv, text)
         return ctext
 
+
 def strip_tags(text):
     if text is None:
         return ''
@@ -202,13 +217,10 @@ def strip_tags(text):
             stop = text[start:].find(">")
             if stop >= 0:
                 # if it does, strip it, and continue loop
-                text = text[:start] + text[start+stop+1:]
+                text = text[:start] + text[start + stop + 1:]
                 finished = 0
     return text
 
-def save_pixmap(self, pixmap, filename):
-    """XXX: deprecated"""
-    pixmap.save(filename, "jpeg", {"quality":"70"})
 
 def clean(text):
     t = strip_tags(text)
@@ -217,6 +229,7 @@ def clean(text):
     t = string.replace(t, '&#160;', ' ')
     return string.strip(t)
 
+
 def gdecode(txt, encode):
     try:
         return txt.decode(encode)
@@ -225,7 +238,8 @@ def gdecode(txt, encode):
 
 # Messages
 
-def error(self, msg, parent=None):
+
+def error(msg, parent=None):
     dialog = gtk.MessageDialog(parent,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
             gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, msg)
@@ -233,6 +247,7 @@ def error(self, msg, parent=None):
     dialog.run()
     dialog.destroy()
 
+
 def urllib_error(msg, parent=None):
     dialog = gtk.MessageDialog(parent,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
@@ -241,6 +256,7 @@ def urllib_error(msg, parent=None):
     dialog.run()
     dialog.destroy()
 
+
 def warning(msg, parent=None):
     dialog = gtk.MessageDialog(parent,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
@@ -249,6 +265,7 @@ def warning(msg, parent=None):
     dialog.run()
     dialog.destroy()
 
+
 def info(msg, parent=None):
     dialog = gtk.MessageDialog(parent,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
@@ -257,7 +274,8 @@ def info(msg, parent=None):
     dialog.run()
     dialog.destroy()
 
-def question(msg, cancel=True, window=None):
+
+def question(msg, window=None):
     dialog = gtk.MessageDialog(window,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
             gtk.MESSAGE_QUESTION, gtk.BUTTONS_NONE, msg)
@@ -267,7 +285,42 @@ def question(msg, cancel=True, window=None):
     dialog.set_skip_taskbar_hint(False)
     response = dialog.run()
     dialog.destroy()
-    return response
+    return response in (gtk.RESPONSE_OK, gtk.RESPONSE_YES)
+
+
+def popup_message(message):
+    """shows popup message while executing decorated function"""
+
+    def wrap(f):
+
+        def wrapped_f(*args, **kwargs):
+            if gtk:
+                window = gtk.Window()
+                window.set_title('Griffith info')
+                window.set_position(gtk.WIN_POS_CENTER)
+                window.set_keep_above(True)
+                window.stick()
+                window.set_default_size(200, 50)
+                label = gtk.Label()
+                label.set_markup("""<big><b>Griffith:</b>
+%s</big>""" % message)
+                window.add(label)
+                window.set_modal(True)
+                window.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
+                window.show_all()
+                while gtk.events_pending():    # give GTK some time for updates
+                    gtk.main_iteration()
+            else:
+                print message,
+            res = f(*args, **kwargs)
+            if gtk:
+                window.destroy()
+            else:
+                print ' [done]'
+            return res
+        return wrapped_f
+    return wrap
+
 
 def file_chooser(title, action=None, buttons=None, name='', folder=os.path.expanduser('~'), picture=False, backup=False):
     dialog = gtk.FileChooserDialog(title=title, action=action, buttons=buttons)
@@ -314,6 +367,7 @@ def file_chooser(title, action=None, buttons=None, name='', folder=os.path.expan
     dialog.destroy()
     return filename, path
 
+
 def update_preview_cb(file_chooser, preview):
     filename = file_chooser.get_preview_filename()
     try:
@@ -325,56 +379,58 @@ def update_preview_cb(file_chooser, preview):
     file_chooser.set_preview_widget_active(have_preview)
     return
 
+
 def run_browser(url):
     webbrowser.register('open', webbrowser.GenericBrowser("open '%s'"))
     webbrowser._tryorder.append('open')
     webbrowser.open(url)
 
+
 def read_plugins(prefix, directory):
     """returns available plugins"""
 
     import glob
-    return glob.glob("%s/%s*.py" % (directory,prefix) )
+    return glob.glob("%s/%s*.py" % (directory, prefix))
+
 
 def findKey(val, dict):
     for key, value in dict.items():
-        if value == val: return key
+        if value == val:
+            return key
     return None
 
+
 def garbage(handler):
     pass
 
+
 def clean_posters_dir(self):
     posters_dir = self.locations['posters']
-
     counter = 0
 
-    for files in os.walk(posters_dir):
-        for names in files:
-            for name in names:
-                if not name.endswith('_m.jpg') and not name.endswith('_s.jpg'):
-                    poster_md5 = gutils.md5sum(file(name, 'rb'))
-                    # lets check if this poster is orphan
-                    used = self.db.session.query(db.Poster).count_by(md5sum=poster_md5)
-                    if not used:
-                        counter += 1
-                        os.unlink(os.path.join(posters_dir, name))
-                        m_file = os.path.join(posters_dir, "m_"+name)
-                        if os.path.isfile(m_file):
-                            os.unlink(m_file)
-                        t_file = os.path.join(posters_dir, "t_"+name)
-                        if os.path.isfile(t_file):
-                            os.unlink(t_file)
+    for dirpath, dirnames, filenames in os.walk(posters_dir):
+        for name in filenames:
+            filepath = os.path.join(dirpath, name)
+            if name.endswith('_m.jpg') or name.endswith('_s.jpg'):
+                # it's safe to remove all thumbs, they'll be regenerated later
+                os.unlink(filepath)
+            else:
+                poster_md5 = md5sum(file(filepath, 'rb'))
+                # lets check if this poster is orphan
+                used = self.db.session.query(db.Poster).filter(db.Poster.md5sum == poster_md5).count()
+                if not used:
+                    counter += 1
+                    os.unlink(filepath)
 
     if counter:
-        print "%d orphan files cleaned." %counter
+        print "%d orphan files cleaned." % counter
     else:
         print "No orphan files found."
 
+
 def decompress(data):
-    import gzip, StringIO
     try:
-        compressedStream = StringIO.StringIO(data)
+        compressedStream = StringIO(data)
         gzipper = gzip.GzipFile(fileobj=compressedStream)
         data = gzipper.read()
     except Exception, e:
@@ -382,19 +438,19 @@ def decompress(data):
         pass
     return data
 
+
 def get_dependencies():
     depend = []
 
     # Python version
     if sys.version_info[:2] < (2, 5):
         depend.append({'module': 'python',
-            'version'    : '-'+'.'.join(map(str,sys.version_info)),
-            'module_req' : '2.5',
-            'url'        : 'http://www.python.org/',
-            'debian'     : 'python',
-            'debian_req' : '2.5'
+            'version': '-' + '.'.join(map(str, sys.version_info)),
+            'module_req': '2.5',
+            'url': 'http://www.python.org/',
+            'debian': 'python',
+            'debian_req': '2.5'})
             # TODO: 'fedora', 'suse', etc.
-        })
 
     try:
         import gtk
@@ -404,13 +460,12 @@ def get_dependencies():
     except:
         version = False
     depend.append({'module': 'gtk',
-        'version'    : version,
-        'module_req' : '2.6',
-        'url'        : 'http://www.pygtk.org/',
-        'debian'     : 'python-gtk2',
-        'debian_req' : '2.8.6-1'
+        'version': version,
+        'module_req': '2.6',
+        'url': 'http://www.pygtk.org/',
+        'debian': 'python-gtk2',
+        'debian_req': '2.8.6-1'})
         # TODO: 'fedora', 'suse', etc.
-    })
 
     try:
         import gtk.glade
@@ -418,12 +473,11 @@ def get_dependencies():
     except:
         version = False
     depend.append({'module': 'gtk.glade',
-        'version'    : version,
-        'module_req' : '2.6',
-        'url'        : 'http://www.pygtk.org/',
-        'debian'     : 'python-glade2',
-        'debian_req' : '2.8.6-1'
-    })
+        'version': version,
+        'module_req': '2.6',
+        'url': 'http://www.pygtk.org/',
+        'debian': 'python-glade2',
+        'debian_req': '2.8.6-1'})
     try:
         import sqlalchemy
         if map(int, sqlalchemy.__version__.split('.')[:2]) < [0, 5]:
@@ -433,12 +487,11 @@ def get_dependencies():
     except:
         version = False
     depend.append({'module': 'sqlalchemy',
-        'version'    : version,
-        'module_req' : '0.5rc3',
-        'url'        : 'http://www.sqlalchemy.org/',
-        'debian'     : 'python-sqlalchemy',
-        'debian_req' : '0.5~rc3'
-    })
+        'version': version,
+        'module_req': '0.5rc3',
+        'url': 'http://www.sqlalchemy.org/',
+        'debian': 'python-sqlalchemy',
+        'debian_req': '0.5~rc3'})
     try:
         import sqlite3
         version = sqlite3.version
@@ -451,40 +504,36 @@ def get_dependencies():
         except:
             version = False
         depend.append({'module': 'pysqlite2',
-            'version'    : version,
-            'url'        : 'http://initd.org/tracker/pysqlite',
-            'debian'     : 'python-pysqlite2',
-            'debian_req' : '2.3.0-1'
-        })
+            'version': version,
+            'url': 'http://initd.org/tracker/pysqlite',
+            'debian': 'python-pysqlite2',
+            'debian_req': '2.3.0-1'})
     else:
         depend.append({'module': 'sqlite3',
-            'version'    : version,
-            'url'        : 'http://www.python.org',
-            'debian'     : 'python',
-            'debian_req' : '2.5'
-        })
+            'version': version,
+            'url': 'http://www.python.org',
+            'debian': 'python',
+            'debian_req': '2.5'})
     try:
         import reportlab
         version = reportlab.Version
     except:
         version = False
     depend.append({'module': 'reportlab',
-        'version'    : version,
-        'url'        : 'http://www.reportlab.org/',
-        'debian'     : 'python-reportlab',
-        'debian_req' : '1.20debian-6'
-    })
+        'version': version,
+        'url': 'http://www.reportlab.org/',
+        'debian': 'python-reportlab',
+        'debian_req': '1.20debian-6'})
     try:
         import PIL
         version = True
     except:
         version = False
     depend.append({'module': 'PIL',
-        'version'    : version,
-        'url'        : 'http://www.pythonware.com/products/pil/',
-        'debian'     : 'python-imaging',
-        'debian_req' : '1.1.5-6'
-    })
+        'version': version,
+        'url': 'http://www.pythonware.com/products/pil/',
+        'debian': 'python-imaging',
+        'debian_req': '1.1.5-6'})
     # extra dependencies:
     optional = []
     try:
@@ -493,44 +542,41 @@ def get_dependencies():
     except:
         version = False
     optional.append({'module': 'psycopg2',
-        'version'    : version,
-        'url'        : 'http://initd.org/tracker/psycopg/wiki/PsycopgTwo',
-        'debian'     : 'python-psycopg2',
-        'debian_req' : '1.1.21-6'
-    })
+        'version': version,
+        'url': 'http://initd.org/tracker/psycopg/wiki/PsycopgTwo',
+        'debian': 'python-psycopg2',
+        'debian_req': '1.1.21-6'})
     try:
         import MySQLdb
-        version    = '.'.join([str(i) for i in MySQLdb.version_info])
+        version = '.'.join([str(i) for i in MySQLdb.version_info])
     except:
         version = False
     optional.append({'module': 'MySQLdb',
-        'version'    : version,
-        'url'        : 'http://sourceforge.net/projects/mysql-python',
-        'debian'     : 'python-mysqldb',
-        'debian_req' : '1.2.1-p2-2'
-    })
+        'version': version,
+        'url': 'http://sourceforge.net/projects/mysql-python',
+        'debian': 'python-mysqldb',
+        'debian_req': '1.2.1-p2-2'})
     try:
         import chardet
-        version    = chardet.__version__
+        version = chardet.__version__
     except:
         version = False
     optional.append({'module': 'chardet',
-        'version' : version,
-        'url'     : 'http://chardet.feedparser.org/',
-        'debian'  : 'python-chardet'
-    })
+        'version': version,
+        'url': 'http://chardet.feedparser.org/',
+        'debian': 'python-chardet'})
     try:
         import sqlite
-        version    = sqlite.version
+        version = sqlite.version
     except:
         version = False
     optional.append({'module': 'sqlite',
-        'version' : version,
-        'url'     : 'http://initd.org/tracker/pysqlite',
-        'debian'  : 'python-sqlite'
-    })
+        'version': version,
+        'url': 'http://initd.org/tracker/pysqlite',
+        'debian': 'python-sqlite'})
     return depend, optional
 
+
 def html_encode(s):
     if not isinstance(s, basestring):
         s = str(s)
@@ -540,10 +586,10 @@ def html_encode(s):
     s = s.replace('"', '&quot;')
     return s
 
+
 def digits_only(s, maximum=None):
     if s is None:
         return 0
-    import string, re
     match = re.compile(r"\d+")
     a = match.findall(str(s))
     if len(a):
@@ -558,6 +604,7 @@ def digits_only(s, maximum=None):
         else:
             return s
 
+
 def copytree(src, dst, symlinks=False):
     """Recursively copy a directory tree using copy2().
 
@@ -586,13 +633,15 @@ def copytree(src, dst, symlinks=False):
         except EnvironmentError, err:
             errors.extend(err.args[0])
     if errors:
-        raise EnvironmentError, errors
+        raise EnvironmentError(errors)
+
 
 def is_windows_system():
     if os.name == 'nt' or os.name.startswith('win'): # win32, win64
         return True
     return False
 
+
 def md5sum(fobj):
     """Returns an md5 hash for an object with read() method."""
     try:
@@ -601,14 +650,53 @@ def md5sum(fobj):
     except ImportError:
         import md5
         m = md5.new()
-    while True:
-        d = fobj.read(8096)
-        if not d:
-            break
-        m.update(d)
+    if hasattr(fobj, 'read'):
+        while True:
+            d = fobj.read(8096)
+            if not d:
+                break
+            m.update(d)
+    else:
+        m.update(fobj)
     return unicode(m.hexdigest())
 
+
 def create_image_cache(md5sum, gsql):
+    session = gsql.Session()
+    poster = session.query(db.Poster).filter_by(md5sum=md5sum).first()
+    if not poster:
+        log.warn("poster not available: %s", md5sum)
+        return False
+    if not poster.data:
+        log.warn("poster data not available: %s", md5sum)
+        return False
+
+    fn_big = os.path.join(gsql.data_dir, 'posters', md5sum + '.jpg')
+    fn_medium = os.path.join(gsql.data_dir, 'posters', md5sum + '_m.jpg')
+    fn_small = os.path.join(gsql.data_dir, 'posters', md5sum + '_s.jpg')
+
+    if not os.path.isfile(fn_big):
+        f = file(fn_big, 'wb')
+        f.write(poster.data)
+        f.close()
+
+    image = gtk.Image()
+    image.set_from_file(fn_big)
+
+    if not os.path.isfile(fn_medium):
+        pixbuf = image.get_pixbuf()
+        pixbuf = pixbuf.scale_simple(100, 140, 'bilinear')
+        pixbuf.save(fn_medium, 'jpeg', {'quality': '70'})
+
+    if not os.path.isfile(fn_small):
+        pixbuf = image.get_pixbuf()
+        pixbuf = pixbuf.scale_simple(30, 40, 'bilinear')
+        pixbuf.save(fn_small, 'jpeg', {'quality': '70'})
+
+    return True
+
+
+def create_imagefile(destdir, md5sum, gsql, destfilename=None):
     poster = gsql.session.query(db.Poster).filter_by(md5sum=md5sum).first()
     if not poster:
         log.warn("poster not available: %s", md5sum)
@@ -616,31 +704,20 @@ def create_image_cache(md5sum, gsql):
     if not poster.data:
         log.warn("poster data not available: %s", md5sum)
         return False
-    
-    fn_big    = os.path.join(gsql.data_dir, 'posters', md5sum+'.jpg')
-    fn_medium = os.path.join(gsql.data_dir, 'posters', md5sum+'_m.jpg')
-    fn_small  = os.path.join(gsql.data_dir, 'posters', md5sum+'_s.jpg')
 
-    if not os.path.isfile(fn_big):
-        f = file(fn_big, 'wb')
+    if destfilename:
+        fulldestpath = os.path.join(destdir, destfilename + '.jpg')
+    else:
+        fulldestpath = os.path.join(destdir, md5sum + '.jpg')
+
+    f = file(fulldestpath, 'wb')
+    try:
         f.write(poster.data)
+    finally:
         f.close()
-    
-    image = gtk.Image()
-    image.set_from_file(fn_big)
-
-    if not os.path.isfile(fn_medium):
-        pixbuf = image.get_pixbuf()
-        pixbuf = pixbuf.scale_simple(100, 140, 'bilinear')
-        pixbuf.save(fn_medium, "jpeg", {"quality":"70"})
-    
-    if not os.path.isfile(fn_small):
-        pixbuf = image.get_pixbuf()
-        pixbuf = pixbuf.scale_simple(30, 40, 'bilinear')
-        pixbuf.save(fn_small, "jpeg", {"quality":"70"})
 
     return True
-        
+
 
 def get_image_fname(md5sum, gsql, size=None):
     """size: s - small; m - medium, b or None - big"""
@@ -649,12 +726,22 @@ def get_image_fname(md5sum, gsql, size=None):
     if not md5sum:
         raise TypeError("md5sum not set")
 
-    if not size or size=='b': size=''
-    else: size = "_%s" % size
+    if not size or size == 'b':
+        size = ''
+    else:
+        size = "_%s" % size
 
-    file_name = os.path.join(gsql.data_dir, 'posters', md5sum+size+'.jpg')
+    file_name = os.path.join(gsql.data_dir, 'posters', md5sum + size + '.jpg')
 
     if not os.path.isfile(file_name) and not create_image_cache(md5sum, gsql):
+        log.warn("Can't create image file %s for md5sum %s" % (file_name, md5sum))
         return False
     return file_name
 
+
+def get_defaultimage_fname(self):
+    return os.path.join(self.locations['images'], 'default.png')
+
+
+def get_defaultthumbnail_fname(self):
+    return os.path.join(self.locations['images'], 'default_thumbnail.png')
