@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: PluginExportHTML.py 1259 2009-07-12 18:43:12Z piotrek $'
+__revision__ = '$Id: PluginExportHTML.py 1388 2010-01-06 21:02:22Z piotrek $'
 
 # Copyright (c) 2005-2009 Piotr Ożarowski
 #
@@ -551,7 +551,7 @@ class ExportPlugin(Base):
             try:
                 os.mkdir(config['exported_dir'])
             except:
-                gutils.error(self,_("Can't create %s!") % config['exported_dir'])
+                gutils.error(_("Can't create %s!") % config['exported_dir'])
                 return 2
             
         data_path = os.path.join(self.locations['share'], 'export_templates', self.templates[tid]['dir'], 'data')
@@ -581,18 +581,18 @@ class ExportPlugin(Base):
             
             posters_dir = os.path.join(config['exported_dir'], 'posters')
             if os.path.isdir(posters_dir):
-                if gutils.question(_("Directory %s already exists.\nDo you want to overwrite it?") % posters_dir, True, self.widgets['window']) == gtk.RESPONSE_YES:
+                if gutils.question(_("Directory %s already exists.\nDo you want to overwrite it?") % posters_dir, self.widgets['window']):
                     try:
                         shutil.rmtree(posters_dir)
                     except:
-                        gutils.error(self,_("Can't remove %s!") % config['exported_dir'])
+                        gutils.error(_("Can't remove %s!") % config['exported_dir'])
                         return 3
                 else:
                     return 4
             try:
                 os.mkdir(posters_dir)
             except:
-                gutils.error(self,_("Can't create %s!") % posters_dir)
+                gutils.error(_("Can't create %s!") % posters_dir)
                 return 5
 
         if config['custom_style']:
@@ -635,7 +635,7 @@ class ExportPlugin(Base):
             filename = 'page.tpl'
             tpl_header = file(os.path.join(template_dir,filename), "r").read()
         except:
-            gutils.error(self,_("Can't open %s!")%filename)
+            gutils.error(_("Can't open %s!")%filename)
             return False
 
         tpl_header = self.fill_template(tpl_header, 'header', config['title'])
@@ -689,7 +689,7 @@ class ExportPlugin(Base):
                 try:
                     exported_file = file(filename, 'w')
                 except:
-                    gutils.error(self,_("Can't create %s!")%filename)
+                    gutils.error(_("Can't create %s!")%filename)
                     return False
                 tmp2 = tpl_header + ''
                 exported_file.write(self.fill_template(tmp2, 'page', str(page)))
