@@ -24,7 +24,6 @@ __revision__ = '$Id$'
 import gutils
 import movie
 import string
-import re
 import amazon
 import threading
 import gtk
@@ -39,7 +38,8 @@ plugin_url          = "www.amazon.com/.uk/.de/.ca/.fr/.jp"
 plugin_language     = _("International")
 plugin_author       = "Michael Jahn"
 plugin_author_email = "<mikej06@hotmail.com>"
-plugin_version      = "1.1"
+plugin_version      = "1.2"
+
 
 class Plugin(movie.Movie):
 
@@ -53,16 +53,23 @@ class Plugin(movie.Movie):
         # use the Amazon Web API
         self.parent_window = parent_window
         try:
-            locale = self.config.get('amazon_locale', 0, section='add')
-            if locale == '1':
+            accesskey = self.config.get('amazon_accesskey', None, section='extensions')
+            secretkey = self.config.get('amazon_secretkey', None, section='extensions')
+            if not accesskey or not secretkey:
+                gutils.error(_('Please configure your Amazon Access Key ID and Secret Key correctly in the preferences dialog.'))
+                return False
+            amazon.setLicense(accesskey, secretkey)
+
+            locale = self.config.get('amazon_locale', 0, section='extensions')
+            if locale == '1' or locale == 'UK':
                 locale = 'uk'
-            elif locale == '2':
+            elif locale == '2' or locale == 'DE':
                 locale = 'de'
-            elif locale == '3':
+            elif locale == '3' or locale == 'CA':
                 locale = 'ca'
-            elif locale == '4':
+            elif locale == '4' or locale == 'FR':
                 locale = 'fr'
-            elif locale == '5':
+            elif locale == '5' or locale == 'JP':
                 locale = 'jp'
             else:
                 locale = None
@@ -76,7 +83,7 @@ class Plugin(movie.Movie):
         except:
             self.page = ''
             try:
-                log.error("Error retrieving results from amazon.")
+                log.exception('Error retrieving results from amazon.')
                 log.error(retriever.result.Request.Errors.Error.Message)
             except:
                 pass
@@ -92,25 +99,25 @@ class Plugin(movie.Movie):
             self.image_url = self.page.SmallImage.URL
 
     def get_o_title(self):
-        if hasattr(self.page.ItemAttributes, 'Title'):
-            self.o_title = self.page.ItemAttributes.Title
-        else:
-            self.director = ''
+        self.o_title = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'Title'):
+                self.o_title = self.page.ItemAttributes.Title
 
     def get_title(self):
-        if hasattr(self.page.ItemAttributes, 'Title'):
-            self.title = self.page.ItemAttributes.Title
-        else:
-            self.director = ''
+        self.title = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'Title'):
+                self.title = self.page.ItemAttributes.Title
 
     def get_director(self):
-        if hasattr(self.page.ItemAttributes, 'Director'):
-            if isinstance(self.page.ItemAttributes.Director, list):
-                self.director = string.join(self.page.ItemAttributes.Director, ', ')
-            else:
-                self.director = self.page.ItemAttributes.Director
-        else:
-            self.director = ''
+        self.director = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'Director'):
+                if isinstance(self.page.ItemAttributes.Director, list):
+                    self.director = string.join(self.page.ItemAttributes.Director, ', ')
+                else:
+                    self.director = self.page.ItemAttributes.Director
 
     def get_plot(self):
         self.plot = ''
@@ -127,18 +134,18 @@ class Plugin(movie.Movie):
                         self.plot = self.page.EditorialReviews.EditorialReview.Content
 
     def get_year(self):
-        if hasattr(self.page.ItemAttributes, 'TheatricalReleaseDate'):
-            self.year = self.page.ItemAttributes.TheatricalReleaseDate[:4]
-        elif hasattr(self.page.ItemAttributes, 'ReleaseDate'):
-            self.year = self.page.ItemAttributes.ReleaseDate[:4]
-        else:
-            self.year = ''
+        self.year = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'TheatricalReleaseDate'):
+                self.year = self.page.ItemAttributes.TheatricalReleaseDate[:4]
+            elif hasattr(self.page.ItemAttributes, 'ReleaseDate'):
+                self.year = self.page.ItemAttributes.ReleaseDate[:4]
 
     def get_runtime(self):
-        if hasattr(self.page.ItemAttributes, 'RunningTime'):
-            self.runtime = self.page.ItemAttributes.RunningTime
-        else:
-            self.runtime = ''
+        self.runtime = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'RunningTime'):
+                self.runtime = self.page.ItemAttributes.RunningTime
 
     def get_genre(self):
         # BrowseNodeId 547664 (Genres)
@@ -157,23 +164,24 @@ class Plugin(movie.Movie):
 
     def get_cast(self):
         self.cast = ''
-        if hasattr(self.page.ItemAttributes, 'Actor'):
-            if isinstance(self.page.ItemAttributes.Actor, list):
-                self.cast = string.join(self.page.ItemAttributes.Actor, '\n')
-            else:
-                self.cast = self.page.ItemAttributes.Actor
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'Actor'):
+                if isinstance(self.page.ItemAttributes.Actor, list):
+                    self.cast = string.join(self.page.ItemAttributes.Actor, '\n')
+                else:
+                    self.cast = self.page.ItemAttributes.Actor
 
     def get_classification(self):
-        if hasattr(self.page.ItemAttributes, 'AudienceRating'):
-            self.classification = self.page.ItemAttributes.AudienceRating
-        else:
-            self.classification = ''
+        self.classification = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'AudienceRating'):
+                self.classification = self.page.ItemAttributes.AudienceRating
 
     def get_studio(self):
-        if hasattr(self.page.ItemAttributes, 'Studio'):
-            self.studio = self.page.ItemAttributes.Studio
-        else:
-            self.studio = ''
+        self.studio = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'Studio'):
+                self.studio = self.page.ItemAttributes.Studio
 
     def get_o_site(self):
         self.o_site = ''
@@ -215,12 +223,16 @@ class Plugin(movie.Movie):
 
     def get_notes(self):
         self.notes = ''
-        if hasattr(self.page.ItemAttributes, 'EAN'):
-            self.notes = 'EAN: ' + self.page.ItemAttributes.EAN
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'EAN'):
+                self.notes = 'EAN: ' + self.page.ItemAttributes.EAN
 
     def get_barcode(self):
-        if hasattr(self.page.ItemAttributes, 'EAN'):
-            self.barcode = self.page.ItemAttributes.EAN
+        self.barcode = ''
+        if hasattr(self.page, 'ItemAttributes'):
+            if hasattr(self.page.ItemAttributes, 'EAN'):
+                self.barcode = self.page.ItemAttributes.EAN
+
 
 class SearchPlugin(movie.SearchMovie):
 
@@ -230,22 +242,29 @@ class SearchPlugin(movie.SearchMovie):
         self.encode                = 'utf8'
         self.remove_accents        = False
 
-    def search(self,parent_window):
+    def search(self, parent_window):
         # dont use base functionality
         # use the Amazon Web API
         self.titles = [""]
         self.ids = [""]
         try:
-            locale = self.config.get('amazon_locale', 0, section='add')
-            if locale == '1':
+            accesskey = self.config.get('amazon_accesskey', None, section='extensions')
+            secretkey = self.config.get('amazon_secretkey', None, section='extensions')
+            if not accesskey or not secretkey:
+                gutils.error(_('Please configure your Amazon Access Key ID and Secret Key correctly in the preferences dialog.'))
+                return False
+            amazon.setLicense(accesskey, secretkey)
+
+            locale = self.config.get('amazon_locale', 0, section='extensions')
+            if locale == '1' or locale == 'UK':
                 locale = 'uk'
-            elif locale == '2':
+            elif locale == '2' or locale == 'DE':
                 locale = 'de'
-            elif locale == '3':
+            elif locale == '3' or locale == 'CA':
                 locale = 'ca'
-            elif locale == '4':
+            elif locale == '4' or locale == 'FR':
                 locale = 'fr'
-            elif locale == '5':
+            elif locale == '5' or locale == 'JP':
                 locale = 'jp'
             else:
                 locale = None
@@ -258,7 +277,7 @@ class SearchPlugin(movie.SearchMovie):
             self.page = retriever.result
         except:
             try:
-                log.error("Error retrieving results from amazon.")
+                log.exception('Error retrieving results from amazon.')
                 log.error(retriever.result.Request.Errors.Error.Message)
             except:
                 pass
@@ -295,6 +314,7 @@ class SearchPlugin(movie.SearchMovie):
             theatricalReleaseDate = ''
         self.titles.append("%s%s%s (ASIN: %s)" % (productGroup, title, theatricalReleaseDate, item.ASIN))
 
+
 class AmazonRetriever(threading.Thread):
 
     def __init__(self, title, locale, parent_window, progress, lookuptype='Search', destination=None):
@@ -319,7 +339,6 @@ class AmazonRetriever(threading.Thread):
     def run_search(self):
         self.result = []
         try:
-            amazon.setLicense('04GDDMMXX8X9CJ1B22G2')
             try:
                 tmp = amazon.searchByTitle(self.title, type='ItemAttributes', product_line='Video', locale=self.locale, page=1)
                 self.result.append(tmp)
@@ -330,8 +349,8 @@ class AmazonRetriever(threading.Thread):
                         tmp = amazon.searchByTitle(self.title, type='ItemAttributes', product_line='Video', locale=self.locale, page=page)
                         self.result.append(tmp)
                         page = page + 1
-            except amazon.AmazonError, e:
-                log.error(e.Message)
+            except amazon.AmazonError:
+                log.exception('Error retrieving results from amazon.')
             # if all digits then try to find an EAN / UPC
             if self.title.isdigit():
                 if len(self.title) == 13:
@@ -339,46 +358,51 @@ class AmazonRetriever(threading.Thread):
                         tmp = amazon.searchByEAN(self.title, type='ItemAttributes', product_line='Video', locale=self.locale)
                         self.result.append(tmp)
                     except amazon.AmazonError, e:
-                        log.error(e.Message)
+                        log.exception('Error retrieving results from amazon.')
                 elif len(self.title) == 12:
                     try:
                         tmp = amazon.searchByUPC(self.title, type='ItemAttributes', product_line='Video', locale=self.locale)
                         self.result.append(tmp)
                     except amazon.AmazonError, e:
-                        log.error(e.Message)
+                        log.exception('Error retrieving results from amazon.')
         except IOError:
-            self.progress.dialog.hide()
-            gutils.urllib_error(_('Connection error'), self.parent_window)
-            self.suspend()
+            log.exception('Error retrieving results from amazon.')
+            #self.progress.dialog.hide()
+            #gutils.urllib_error(_('Connection error'), self.parent_window)
+            #self.suspend()
 
     def run_get(self):
         self.result = None
         try:
-            amazon.setLicense('04GDDMMXX8X9CJ1B22G2')
             # get by ASIN
             try:
                 self.result = amazon.searchByASIN(self.title, type='Large', locale=self.locale)
             except amazon.AmazonError, e:
-                log.error(e.Message)
+                log.exception('Error retrieving results from amazon.')
         except IOError:
-            self.progress.dialog.hide()
-            gutils.urllib_error(_('Connection error'), self.parent_window)
-            self.suspend()
+            log.exception('Error retrieving results from amazon.')
+            #self.progress.dialog.hide()
+            #gutils.urllib_error(_('Connection error'), self.parent_window)
+            #self.suspend()
+
 
 #
 # Plugin Test
 #
+# Amazon test data for DE locale only
+#
 class SearchPluginTest(SearchPlugin):
     #
     # Configuration for automated tests:
     # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
     #
     test_configuration = {
-        'Rocky Balboa'         : [ 16, 16 ],
+        'Rocky Balboa'         : [ 17, 17 ],
         'Arahan'               : [  7,  7 ],
-        'Ein glückliches Jahr' : [  2,  2 ]
+        'Ein glückliches Jahr' : [  3,  3 ]
     }
 
+
 class PluginTest:
     #
     # Configuration for automated tests:
@@ -441,7 +465,7 @@ Charles Gérard',
 Yoon So-yi\n\
 Ahn Sung-kee',
             'country'             : 'Südkorea',
-            'genre'               : 'Actionkomödie, Abenteuer- & Actionkomödie, Fantasykomödie, General AAS, Action, Komödie, Action, Fantasy, Komödie, Korea, Unter 10 EUR',
+            'genre'               : 'Actionkomödie, Abenteuer- & Actionkomödie, Fantasykomödie, General AAS, Action, Komödie, Action, Fantasy, Komödie, Korea',
             'classification'      : 'Freigegeben ab 16 Jahren',
             'o_site'              : False,
             'site'                : 'http://www.amazon.de/dp/B000BSNOD6',
