@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMovieE-Pipoca.py 1188 2009-04-16 20:23:17Z mikej06 $'
+__revision__ = '$Id: PluginMovieE-Pipoca.py 1327 2009-12-08 20:38:46Z mikej06 $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -231,7 +231,7 @@ Jack Lazzarado' + _(' as ') + 'Inspetor de Dixon\n\
 Michael Buffer' + _(' as ') + 'Anunciador de luta\n\
 Joe Cortez' + _(' as ') + 'Árbitro\n\
 Carter Mitchell' + _(' as ') + 'Shamrock Foreman\n\
-Vinod Kumar' + _(' as ') + 'Ravi\n\
+Vinod Kumar (1)' + _(' as ') + 'Ravi\n\
 Fran Pultro' + _(' as ') + 'Pai no restaurante\n\
 Frank Stallone Jr.¹' + _(' as ') + 'Cliente do restaurante\n\
 Jody Giambelluca' + _(' as ') + 'Cliente do restaurante\n\
