@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMovieIMDB.py 1233 2009-07-03 14:12:47Z mikej06 $'
+__revision__ = '$Id: PluginMovieIMDB.py 1327 2009-12-08 20:38:46Z mikej06 $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -254,8 +254,8 @@ class SearchPluginTest(SearchPlugin):
     # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
     #
     test_configuration = {
-        'Rocky Balboa'         : [ 15, 15 ],
-        'Ein glückliches Jahr' : [ 22, 22 ]
+        'Rocky Balboa'         : [ 17, 17 ],
+        'Ein glückliches Jahr' : [ 24, 24 ]
     }
 
 class PluginTest:
@@ -275,7 +275,7 @@ class PluginTest:
             'cast'              : 'Geoffrey Rush' + _(' as ') + 'Philip Henslowe\n\
 Tom Wilkinson' + _(' as ') + 'Hugh Fennyman\n\
 Steven O\'Donnell' + _(' as ') + 'Lambert\n\
-Tim McMullan' + _(' as ') + 'Frees\n\
+Tim McMullan' + _(' as ') + 'Frees (as Tim McMullen)\n\
 Joseph Fiennes' + _(' as ') + 'Will Shakespeare\n\
 Steven Beard' + _(' as ') + 'Makepeace - the Preacher\n\
 Antony Sher' + _(' as ') + 'Dr. Moth\n\
@@ -284,7 +284,7 @@ Martin Clunes' + _(' as ') + 'Richard Burbage\n\
 Sandra Reinton' + _(' as ') + 'Rosaline\n\
 Simon Callow' + _(' as ') + 'Tilney - Master of the Revels\n\
 Judi Dench' + _(' as ') + 'Queen Elizabeth\n\
-Bridget McConnell' + _(' as ') + 'Lady in Waiting\n\
+Bridget McConnell' + _(' as ') + 'Lady in Waiting (as Bridget McConnel)\n\
 Georgie Glen' + _(' as ') + 'Lady in Waiting\n\
 Nicholas Boulton' + _(' as ') + 'Henry Condell\n\
 Gwyneth Paltrow' + _(' as ') + 'Viola De Lesseps\n\
