@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMovieOFDb.py 1255 2009-07-06 23:39:05Z mikej06 $'
+__revision__ = '$Id: PluginMovieOFDb.py 1319 2009-11-10 22:10:14Z mikej06 $'
 
 # Written by Christian Sagmueller <christian@sagmueller.net>
 # based on PluginMovieIMDB.py, Copyright (c) 2005 Vasco Nunes
@@ -248,8 +248,8 @@ Ricky Cavazos',
             'director'            : 'Claude Lelouch',
             'plot'                 : False,
             'cast'                : 'Lino Ventura' + _(' as ') + 'Simon \n\
-Françoise Fabian\n\
-Charles Gérard\n\
+Françoise Fabian' + _(' as ') + 'Françoise\n\
+Charles Gérard' + _(' as ') + 'Charlot\n\
 André Falcon' + _(' as ') + 'Le bijoutier\n\
 Mireille Mathieu\n\
 Lilo\n\
