@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: preferences.py 1237 2009-07-04 13:21:34Z piotrek $'
+__revision__ = '$Id: preferences.py 1325 2009-11-22 21:31:47Z mikej06 $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -23,10 +23,12 @@ __revision__ = '$Id: preferences.py 1237 2009-07-04 13:21:34Z piotrek $'
 
 import logging
 import os
+import gtk
 
 import db
 import gutils
 import initialize
+import plugins.extensions
 
 try:
     import gtkspell
@@ -200,8 +202,6 @@ def show_preferences(self, page=None):
 
     w['spell_lang'].set_text(str(self.config.get('lang', 'en', section='spell')))
 
-    w['amazon_locale'].set_active(int(self.config.get('amazon_locale', 0, section='add')))
-
     if page is not None:
         w['notebook'].set_current_page(page)
     w['window'].show()
@@ -382,8 +382,6 @@ def save_preferences(self):
     c.set('lang', w['spell_lang'].get_text(), section='spell')
     c['pdf_reader'] = save_reader
 
-    c.set('amazon_locale', w['amazon_locale'].get_active(), section='add')
-    
     if spell_support:
         if c.get('gtkspell', False, section='spell') == False and not was_false:
             self.notes_spell.detach()
@@ -411,6 +409,24 @@ def save_preferences(self):
                 pass
     self.pdf_reader = save_reader
 
+    # extensions settings
+    for ext_name in plugins.extensions.by_name:
+        preferenceswidgets = plugins.extensions.by_name[ext_name].preferenceswidgets
+        for prefname in preferenceswidgets:
+            widget = preferenceswidgets[prefname]
+            if isinstance(widget, gtk.CheckButton):
+                value = widget.get_active()
+            elif isinstance(widget, gtk.Entry):
+                value = widget.get_text()
+            elif isinstance(widget, gtk.ComboBox):
+                iter = widget.get_active_iter()
+                if iter:
+                    value = widget.get_model().get_value(iter, 1)
+            else:
+                log.error('widget type not supported %s', type(widget))
+                continue
+            c.set("%s_%s" % (ext_name, prefname), value, section='extensions')
+
     # database
     old = c.to_dict(section='database')
     
@@ -445,9 +461,10 @@ def save_preferences(self):
         if c.has_key('posters'):
             c['posters'] = None # force update
         try:
+            self.db.dispose()
             self.db = sql.GriffithSQL(c, self.locations['home'], fallback=True)
         except InvalidRequestError, e:
-            log.error(e)
+            log.exception('')
             c.set('type', 'sqlite', section='database')
             w['db_type'].set_active(0)
             self.db = sql.GriffithSQL(c, self.locations['home'])
@@ -463,3 +480,6 @@ def save_preferences(self):
     self.clear_details()
     self.filter_txt(None)
     c.save()
+    
+    # reload extensions
+    initialize.extensions(self)
