@@ -1,9 +1,9 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: sql.py 1259 2009-07-12 18:43:12Z piotrek $'
+__revision__ = '$Id: sql.py 1338 2009-12-22 19:37:40Z piotrek $'
 
-# Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
+# Copyright © 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,12 +28,13 @@ __revision__ = '$Id: sql.py 1259 2009-07-12 18:43:12Z piotrek $'
 import logging
 import os.path
 
-from sqlalchemy            import *
+from sqlalchemy import create_engine, or_, and_, not_, exists, asc, desc
 from sqlalchemy.exceptions import OperationalError
-from sqlalchemy.orm        import sessionmaker
+from sqlalchemy.orm import sessionmaker
+from sqlalchemy.sql.expression import Update, Delete
 
 import db # ORM data (SQLAlchemy stuff)
-import gutils # TODO: get rid of this import
+from gutils import warning # TODO: get rid of this import
 
 log = logging.getLogger("Griffith")
 
@@ -60,19 +61,20 @@ class GriffithSQL(object):
             if config.get('name', None, section='database') is None:
                 config.set('name', 'griffith', section='database')
             if config.get('port', 0, section='database') == 0:
-                config.set('port', DEFAULT_PORTS[config.get('type', section='database')], section='database')
+                config.set('port', GriffithSQL.DEFAULT_PORTS[config.get('type', section='database')], section='database')
 
         conn_params = config.to_dict(section='database')
-        conn_params['port'] = int(conn_params['port'])
+        conn_params.update({'port': int(conn_params.get('port', 0)),
+                            'engine_kwargs': {'echo': False, 'convert_unicode': False}})
 
         # connect to database --------------------------------------{{{
-        convert_unicode = False # see MySQL
         if config.get('type', section='database') == 'sqlite':
             url = "sqlite:///%s.db" % os.path.join(griffith_dir, conn_params['name'])
         elif config.get('type', section='database') == 'postgres':
             url = "postgres://%(user)s:%(passwd)s@%(host)s:%(port)d/%(name)s" % conn_params
         elif config.get('type', section='database') == 'mysql':
-            convert_unicode = True
+            conn_params['engine_kwargs']['convert_unicode'] = True
+            conn_params['engine_kwargs']['pool_recycle'] = int(config.get('pool_recycle', 3600, section='database'))
             url = "mysql://%(user)s:%(passwd)s@%(host)s:%(port)d/%(name)s?charset=utf8&use_unicode=0" % conn_params
         elif config.get('type', section='database') == 'mssql':
             # use_scope_identity=0 have to be set as workaround for a sqlalchemy bug
@@ -90,14 +92,14 @@ class GriffithSQL(object):
 
         # try to establish a db connection
         try:
-            engine = create_engine(url, echo=False, convert_unicode=convert_unicode)
+            engine = create_engine(url, **conn_params['engine_kwargs'])
             conn = engine.connect()
         except Exception, e:    # InvalidRequestError, ImportError
             log.info("MetaData: %s", e)
             if not fallback:
                 raise e
             config.set('type', 'sqlite', section='database')
-            gutils.warning("%s\n\n%s" % (_('Cannot connect to database.\nFalling back to SQLite.'), _('Please check debug output for more informations.')))
+            warning("%s\n\n%s" % (_('Cannot connect to database.\nFalling back to SQLite.'), _('Please check debug output for more informations.')))
             url = "sqlite:///%s.db" % os.path.join(griffith_dir, conn_params['name'])
             engine = create_engine(url)
             conn = engine.connect()
@@ -126,117 +128,136 @@ class GriffithSQL(object):
                 raise Exception('cannot upgrade database')
         elif v > self.version:
             log.error("database version mismatch (detected:%s; current:%s)", v, self.version)
-            gutils.warning(_('This database requires newer version of Griffith.'))
+            warning(_('This database requires newer version of Griffith.'))
             raise Exception("database version mismatch")
 
+    def dispose(self):
+        # close every session and connection so that a sqlite database file can be removed
+        # otherwise it will remain opened by the current process and can't be deleted
+        try:
+            self.session.close()
+            self.Session.close_all()
+            self.engine.dispose()
+            del self.session
+            del self.Session
+            del self.engine
+        except:
+            log.exception('')
+
 
 def update_whereclause(query, cond): # {{{
     if cond['loaned'] is True:
-        query.append_whereclause(db.Movie.loaned==True)
+        query = query.where(db.Movie.loaned == True)
     if cond['loaned'] is False:
-        query.append_whereclause(db.Movie.loaned==False)
+        query = query.where(db.Movie.loaned == False)
     if cond['seen'] is True:
-        query.append_whereclause(db.Movie.seen==True)
+        query = query.where(db.Movie.seen == True)
     if cond['seen'] is False:
-        query.append_whereclause(db.Movie.seen==False)
+        query = query.where(db.Movie.seen == False)
 
     if cond["collections"]:
-        query.append_whereclause(db.Movie.collection_id.in_(cond["collections"]))
+        query = query.where(db.Movie.collection_id.in_(cond["collections"]))
     if cond["no_collections"]:
-        query.append_whereclause(~db.Movie.collection_id.in_(cond["no_collections"]))
+        query = query.where(~db.Movie.collection_id.in_(cond["no_collections"]))
 
     if cond["volumes"]:
-        query.append_whereclause(db.Movie.volume_id.in_(cond["volumes"]))
+        query = query.where(db.Movie.volume_id.in_(cond["volumes"]))
     if cond["no_volumes"]:
-        query.append_whereclause(~db.Movie.volume_id.in_(cond["no_volumes"]))
+        query = query.where(~db.Movie.volume_id.in_(cond["no_volumes"]))
 
     loaned_to = []
     for per_id in cond["loaned_to"]:
         loaned_to.append(exists([db.tables.loans.c.movie_id],\
-                and_(db.Movie.movie_id==db.tables.loans.c.movie_id, db.tables.loans.c.person_id==per_id, db.tables.loans.c.return_date==None)))
+                and_(db.Movie.movie_id == db.tables.loans.c.movie_id,
+                     db.tables.loans.c.person_id == per_id,
+                     db.tables.loans.c.return_date == None)))
     if loaned_to:
-        query.append_whereclause(or_(*loaned_to))
+        query = query.where(or_(*loaned_to))
 
     loan_history = []
     for per_id in cond["loan_history"]:
         loan_history.append(exists([db.tables.loans.c.movie_id],\
-                and_(db.Movie.movie_id==db.tables.loans.c.movie_id, db.tables.loans.c.person_id==per_id)))
+                and_(db.Movie.movie_id == db.tables.loans.c.movie_id,
+                     db.tables.loans.c.person_id == per_id)))
     if loan_history:
-        query.append_whereclause(or_(*loan_history))
+        query = query.where(or_(*loan_history))
 
     required_tags = []
     for tag_id in cond["required_tags"]:
         required_tags.append(exists([db.MovieTag.movie_id], \
-            and_(db.Movie.movie_id==db.MovieTag.movie_id, db.MovieTag.tag_id==tag_id)))
+            and_(db.Movie.movie_id == db.MovieTag.movie_id,
+                 db.MovieTag.tag_id == tag_id)))
     if required_tags:
-        query.append_whereclause(and_(*required_tags))
+        query = query.where(and_(*required_tags))
 
     tags = []
     for tag_id in cond["tags"]:
         tags.append(exists([db.MovieTag.movie_id], \
-            and_(db.Movie.movie_id==db.MovieTag.movie_id, db.MovieTag.tag_id==tag_id)))
+            and_(db.Movie.movie_id == db.MovieTag.movie_id,
+                 db.MovieTag.tag_id == tag_id)))
     if tags:
-        query.append_whereclause(or_(*tags))
+        query = query.where(or_(*tags))
 
     no_tags = []
     for tag_id in cond["no_tags"]:
         no_tags.append(~exists([db.MovieTag.movie_id], \
-            and_(db.Movie.movie_id==db.MovieTag.movie_id, db.MovieTag.tag_id==tag_id)))
+            and_(db.Movie.movie_id == db.MovieTag.movie_id,
+                 db.MovieTag.tag_id == tag_id)))
     if no_tags:
-        query.append_whereclause(and_(*no_tags))
+        query = query.where(and_(*no_tags))
 
     for field in cond["equals_n"]:
-        values = [ db.tables.movies.columns[field]!=value for value in cond["equals_n"][field] ]
-        query.append_whereclause(and_(*values))
+        values = [db.tables.movies.columns[field] != value for value in cond["equals_n"][field]]
+        query = query.where(and_(*values))
 
     for field in cond["startswith_n"]:
-        values = [ not_(db.tables.movies.columns[field].startswith(value)) for value in cond["startswith_n"][field] ]
-        query.append_whereclause(and_(*values))
+        values = [not_(db.tables.movies.columns[field].startswith(value)) for value in cond["startswith_n"][field]]
+        query = query.where(and_(*values))
 
     for field in cond["like_n"]:
-        values = [ not_(db.tables.movies.columns[field].like(value)) for value in cond["like_n"][field] ]
-        query.append_whereclause(and_(*values))
+        values = [not_(db.tables.movies.columns[field].like(value)) for value in cond["like_n"][field]]
+        query = query.where(and_(*values))
 
     for field in cond["contains_n"]: # XXX: it's not the SQLAlchemy's .contains() i.e. not for one-to-many or many-to-many collections
-        values = [ not_(db.tables.movies.columns[field].like('%'+value+'%')) for value in cond["contains_n"][field] ]
-        query.append_whereclause(and_(*values))
+        values = [not_(db.tables.movies.columns[field].like('%' + value + '%')) for value in cond["contains_n"][field]]
+        query = query.where(and_(*values))
 
     for field in cond["equals"]:
-        values = [ db.tables.movies.columns[field]==value for value in cond["equals"][field] ]
-        query.append_whereclause(or_(*values))
+        values = [db.tables.movies.columns[field] == value for value in cond["equals"][field]]
+        query = query.where(or_(*values))
 
     for field in cond["startswith"]:
-        values = [ db.tables.movies.columns[field].startswith(value) for value in cond["startswith"][field] ]
-        query.append_whereclause(or_(*values))
+        values = [db.tables.movies.columns[field].startswith(value) for value in cond["startswith"][field]]
+        query = query.where(or_(*values))
 
     for field in cond["like"]:
-        values = [ db.tables.movies.columns[field].like(value) for value in cond["like"][field] ]
-        query.append_whereclause(or_(*values))
+        values = [db.tables.movies.columns[field].like(value) for value in cond["like"][field]]
+        query = query.where(or_(*values))
 
     for field in cond["contains"]: # XXX: it's not the SQLAlchemy's .contains() i.e. not for one-to-many or many-to-many collections
-        values = [ db.tables.movies.columns[field].like('%'+value+'%') for value in cond["contains"][field] ]
-        query.append_whereclause(or_(*values))
+        values = [db.tables.movies.columns[field].like('%' + value + '%') for value in cond["contains"][field]]
+        query = query.where(or_(*values))
 
     # sorting
-    for rule in cond["sort_by"]:
-        if rule.endswith(" DESC"):
-            reverse = True
-            column = rule.replace(" DESC", '')
-        else:
-            column = rule.replace(" ASC", '') # note that " ASC" is optional
-            reverse = False
+    if not isinstance(query, (Update, Delete)):
+        for rule in cond.get('sort_by', []):
+            if rule.endswith(" DESC"):
+                reverse = True
+                column = rule.replace(" DESC", '')
+            else:
+                column = rule.replace(" ASC", '') # note that " ASC" is optional
+                reverse = False
 
-        table = 'movies'
-        tmp = column.split('.')
-        if len(tmp) > 1:
-            table = tmp[0]
-            column = tmp[1]
+            table = 'movies'
+            tmp = column.split('.')
+            if len(tmp) > 1:
+                table = tmp[0]
+                column = tmp[1]
 
-        if reverse:
-            query.append_order_by(desc(db.metadata.tables[table].columns[column]))
-        else:
-            query.append_order_by(asc(db.metadata.tables[table].columns[column]))
+            if reverse:
+                query = query.order_by(desc(db.metadata.tables[table].columns[column]))
+            else:
+                query = query.order_by(asc(db.metadata.tables[table].columns[column]))
 
-    log.debug(query.compile())
+    log.debug(query)
     return query #}}}
-
