@@ -1,8 +1,8 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: version.py 1271 2009-08-03 20:28:46Z piotrek $'
+__revision__ = '$Id: version.py 1372 2010-01-04 21:20:40Z piotrek $'
 
-# Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
+# Copyright © 2005-2010 Vasco Nunes, Piotr Ożarowski
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@ __revision__ = '$Id: version.py 1271 2009-08-03 20:28:46Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
-pname        = "Griffith"
-pversion     = "0.10"
-pauthor      = "Vasco Nunes, Piotr Ożarowski <griffith-private@lists.berlios.de>"
-pyear        = "2005-2009"
-pwebsite     = "http://www.griffith.cc/"
-pdescription = _("Griffith is a film collection manager.")
+pname = 'Griffith'
+pversion = '0.11'
+pauthor = 'Vasco Nunes, Piotr Ożarowski <griffith-private@lists.berlios.de>'
+pyear = '2005-2010'
+pwebsite = 'http://www.griffith.cc/'
+pdescription = _('Griffith is a film collection manager.')
